# Summary

* [Introduction](./intro.md)
* [Getting Started](./getting-started.md)
* [Concepts](./concepts/intro.md)
    * [State](./concepts/state.md)
    * [Entity and Component](./concepts/entity_and_component.md)
    * [Resource](./concepts/resource.md)
    * [World](./concepts/world.md)
    * [System](./concepts/system.md)
        * [System Initialization](./concepts/system/system_initialization.md)
        * [SystemDesc Derive](./concepts/system/system_desc_derive.md)
        * [Implementing the SystemDesc Trait](./concepts/system/implementing_the_system_desc_trait.md)
    * [Dispatcher](./concepts/dispatcher.md)
    * [Event Channel](./concepts/event-channel.md)
* [Pong Tutorial](pong-tutorial.md)
    * [Setting up the project](./pong-tutorial/pong-tutorial-01.md)
    * [Drawing the Paddles](./pong-tutorial/pong-tutorial-02.md)
    * [Moving the Paddles](./pong-tutorial/pong-tutorial-03.md)
    * [Making a Ball Move and Bounce](./pong-tutorial/pong-tutorial-04.md)
    * [Winning Rounds and Keeping Score](./pong-tutorial/pong-tutorial-05.md)
    * [Adding audio](./pong-tutorial/pong-tutorial-06.md)
    * [Call for Contribution](./pong-tutorial/contribution.md)
* [Math](./math.md)
* [Input](./input.md)
    * [Handling Input](./input/handling_input.md)
    * [How to Define Custom Control Bindings](./input/how_to_define_custom_control_bindings.md)
* [Assets](./assets.md)
    * [Formats](./assets/formats.md)
    * [How to Use Assets](./assets/how_to_use_assets.md)
    * [How to Define Custom Assets](./assets/how_to_define_custom_assets.md)
    * [How to Define Custom Formats](./assets/how_to_define_custom_formats.md)
* [Prefabs](./prefabs.md)
    * [Prefabs in Amethyst](./prefabs/prefabs_in_amethyst.md)
    * [How to Define Prefabs: Prelude](./prefabs/how_to_define_prefabs_prelude.md)
    * [How to Define Prefabs: Simple](./prefabs/how_to_define_prefabs_simple.md)
    * [How to Define Prefabs: Aggregate](./prefabs/how_to_define_prefabs_aggregate.md)
    * [How to Define Prefabs: Adapter](./prefabs/how_to_define_prefabs_adapter.md)
    * [How to Define Prefabs: Asset](./prefabs/how_to_define_prefabs_asset.md)
    * [How to Define Prefabs: Multi-Handle](./prefabs/how_to_define_prefabs_multi_handle.md)
    * [Prefabs Technical Explanation](./prefabs/prefabs_technical_explanation.md)
* [Animation](./animation.md)
    * [Interpolation](./animation/interpolation.md)
    * [Channel](./animation/channel.md)
    * [Sampler](./animation/sampler.md)
    * [Definition](./animation/definition.md)
* [Controlling System Execution](controlling_system_execution.md)
    * [Custom `GameData`](controlling_system_execution/custom_game_data.md)
    * [State-specific Dispatcher](controlling_system_execution/state-specific_dispatcher.md)
    * [Pausable Systems](controlling_system_execution/pausable_systems.md)
* [Sprites](./sprites.md)
    * [Set Up The Render Pass](./sprites/set_up_the_render_pass.md)
    * [Load The `Texture`](./sprites/load_the_texture.md)
    * [Define The `SpriteSheet`](./sprites/define_the_sprite_sheet.md)
    * [`SpriteRender` Component](./sprites/sprite_render_component.md)
    * [Modify The `Texture`](./sprites/modify_the_texture.md)
    * [Orthographic Camera](./sprites/orthographic_camera.md)
* [Testing](./testing.md)
    * [Test Examples](./testing/test_examples.md)
* [Glossary](./glossary.md)
* [Appendix A: Config Files](./appendices/a_config_files.md)
    * [Adding an Arena Config](./appendices/a_config_files/arena_config.md)
    * [Adding a Ball Config](./appendices/a_config_files/ball_config.md)
    * [Adding Paddle Configs](./appendices/a_config_files/paddle_configs.md)
* [Appendix B: Migration Notes](./appendices/b_migration_notes.md)
    * [`cgmath` to `nalgebra`](./appendices/b_migration_notes/cgmath_to_nalgebra.md)
    * [Rendy Migration](./appendices/b_migration_notes/rendy_migration.md)
    * [Specs Migration](./appendices/b_migration_notes/specs_migration.md)
* [Appendix C: Feature Gates](./appendices/c_feature_gates.md)
